@@ -1,4 +1,4 @@
-/* $Id: error.h,v 1.17 2003/10/19 16:10:17 carlos Exp $ */
+/* $Id: error.h,v 1.18 2003/10/20 15:19:39 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,7 +26,7 @@
 
 #include <glibtop.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #ifndef G_GNUC_UNUSED
 #if	__GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ > 4)
@@ -131,6 +131,6 @@ glibtop_warn_io (char *format, ...)
 
 #endif /* no __GNUC__ */
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
