@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: uptime.h,v 1.24 2003/10/20 21:27:23 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -29,11 +27,11 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_UPTIME_UPTIME		0
 #define GLIBTOP_UPTIME_IDLETIME		1
-#define GLIBTOP_UPTIME_BOOT_TIME	2
+#define GLIBTOP_UPTIME_BOOT_TIME    2
 
 #define GLIBTOP_MAX_UPTIME		3
 
@@ -41,10 +39,10 @@ typedef struct _glibtop_uptime	glibtop_uptime;
 
 struct _glibtop_uptime
 {
-    u_int64_t flags;
-    double uptime,		/* GLIBTOP_UPTIME_UPTIME	*/
-	idletime;		/* GLIBTOP_UPTIME_IDLETIME	*/
-    u_int64_t boot_time;	/* GLIBTOP_UPTIME_BOOT_TIME	*/
+	guint64 flags;
+	double uptime,		/* GLIBTOP_UPTIME_UPTIME	*/
+		idletime;	/* GLIBTOP_UPTIME_IDLETIME	*/
+	guint64 boot_time;
 };
 
 #define glibtop_get_uptime(uptime)	glibtop_get_uptime_l(glibtop_global_server, uptime)
@@ -55,14 +53,14 @@ struct _glibtop_uptime
 #define glibtop_get_uptime_r		glibtop_get_uptime_s
 #endif
 
-int glibtop_get_uptime_l (glibtop *server, glibtop_uptime *buf);
+void glibtop_get_uptime_l (glibtop *server, glibtop_uptime *buf);
 
 #if GLIBTOP_SUID_UPTIME
-int glibtop_init_uptime_p (glibtop *server);
-int glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf);
+void glibtop_init_uptime_p (glibtop *server);
+void glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf);
 #else
-int glibtop_init_uptime_s (glibtop *server);
-int glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf);
+void glibtop_init_uptime_s (glibtop *server);
+void glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf);
 #endif
 
 #ifdef GLIBTOP_NAMES
@@ -76,6 +74,6 @@ extern const char *glibtop_descriptions_uptime [];
 
 #endif
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
