@@ -1,4 +1,4 @@
-/* $Id: read.c,v 1.16 2003/10/20 21:33:01 hadess Exp $ */
+/* $Id: read.c,v 1.17 2004/03/04 15:29:12 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,7 +23,7 @@
 
 #include <config.h>
 #include <glibtop/read.h>
-#include <libgnome/gnome-i18n.h>
+#include "libgtop-i18n.h"
 
 
 /* Reads some data from server. */
