@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: glibtop_machine.h,v 1.13 2004/03/09 23:13:31 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -37,25 +35,33 @@
 
 #include <fcntl.h>
 
-#ifdef HAVE_OSRELDATE_H
+#ifdef __FreeBSD__
 #include <osreldate.h>
 #endif
 
-BEGIN_LIBGTOP_DECLS
+#ifdef __NetBSD__
+#include <sys/proc.h>
+
+#ifndef SRUN
+#define SRUN    SACTIVE
+#endif
+#endif
+
+G_BEGIN_DECLS
 
 typedef struct _glibtop_machine glibtop_machine;
 
 struct _glibtop_machine
 {
-    uid_t uid, euid;
-    gid_t gid, egid;
+	uid_t uid, euid;
+	gid_t gid, egid;
 	
-    /* The kernel descriptor, used by kvm_* calls.  We keep and re-use
-     * it rather than re-getting it for almost all function
-     * invocations. */
-    kvm_t *kd;
+	/* The kernel descriptor, used by kvm_* calls.  We keep and re-use
+	 * it rather than re-getting it for almost all function
+	 * invocations. */
+	kvm_t *kd;
 };
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
-#endif __GLIBTOP_MACHINE_H__
+#endif /* __GLIBTOP_MACHINE_H__ */
