@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: loadavg.c,v 1.8 2003/10/19 16:55:51 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -33,22 +31,18 @@ static const unsigned long _glibtop_sysdeps_loadavg = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_loadavg_p (glibtop *server)
 {
-    server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
-
-    return 0;
+	server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
 }
 
 /* Provides load averange. */
 
-int
+void
 glibtop_get_loadavg_p (glibtop *server, glibtop_loadavg *buf)
 {
-    glibtop_init_p (server, GLIBTOP_SYSDEPS_LOADAVG, 0);
+	glibtop_init_p (server, GLIBTOP_SYSDEPS_LOADAVG, 0);
 	
-    memset (buf, 0, sizeof (glibtop_loadavg));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_loadavg));
 }
